utils

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DayOfYearToMonthDay

func DayOfYearToMonthDay(dayOfYear int, isLeap bool) (month, day int)

dayOfYearToMonthDay converts day of year to month and day

func Days2mdhms

func Days2mdhms(year int64, days float64) (month, day, hour, minute int, second float64)

Days2mdhms converts a float point number of days in a year into date and time components

func ECIToLLA

func ECIToLLA(eciCoords [3]float64, gmst float64) (altitude, velocity float64, ret [2]float64)

Convert Earth Centered Inertial coordinated into equivalent latitude, longitude, altitude and velocity. Reference: http://celestrak.com/columns/v02n03/ and Bowring's method

func NormalizeAngle

func NormalizeAngle(angle float64) float64

Helper function to normalize angles

func ParseFloat

func ParseFloat(strIn string) (ret float64)

func ParseInt

func ParseInt(strIn string) (ret int64)

Parses a string into a int64 value.

func ParseScientificNotation

func ParseScientificNotation(value string) string

Helper function to parse scientific notation in TLE format

func ValidateTLE

func ValidateTLE(line1, line2 string) error

Add validation function

func VerifyChecksum

func VerifyChecksum(line string) bool

Calculate and verify TLE line checksum

Types

This section is empty.

Jump to