Documentation
¶
Index ¶
- func DayOfYearToMonthDay(dayOfYear int, isLeap bool) (month, day int)
- func Days2mdhms(year int64, days float64) (month, day, hour, minute int, second float64)
- func ECIToLLA(eciCoords [3]float64, gmst float64) (altitude, velocity float64, ret [2]float64)
- func NormalizeAngle(angle float64) float64
- func ParseFloat(strIn string) (ret float64)
- func ParseInt(strIn string) (ret int64)
- func ParseScientificNotation(value string) string
- func ValidateTLE(line1, line2 string) error
- func VerifyChecksum(line string) bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DayOfYearToMonthDay ¶
dayOfYearToMonthDay converts day of year to month and day
func Days2mdhms ¶
Days2mdhms converts a float point number of days in a year into date and time components
func ECIToLLA ¶
Convert Earth Centered Inertial coordinated into equivalent latitude, longitude, altitude and velocity. Reference: http://celestrak.com/columns/v02n03/ and Bowring's method
func NormalizeAngle ¶
Helper function to normalize angles
func ParseFloat ¶
func ParseScientificNotation ¶
Helper function to parse scientific notation in TLE format
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.